package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "15.0.1+9-18" },
            { "jdk", "15.0.1" },
            { "release", "15.0.1" },
        };
    }
}
